==> Epics.uv7.24.tar.gz: epics/ZbpTbl.h <==
      integer mxBrTXL, mxBrTblLA, mxBrTblLB
      integer mxPrTXL, mxPrTblLA, mxPrTblLB
      integer mxBrTXH, mxBrTblHA, mxBrTblHB
      integer mxPrTXH, mxPrTblH
      integer mxBrTXS, mxBrTblSA,  mxBrTblSB

c           for muon interaction
      integer mxMuNTX, mxMuBrTX, mxMuPrTX
      integer mxMuNTbl, mxMuBrTbl, mxMuPrTbl
      integer mxMuNUsize, mxMuNEsize, mxMuBrUsize, 
     *        mxMuBrEsize, mxMuPrUsize,mxMuPrEsize

      parameter ( mxBrTXL = 60, mxBrTblLA=mxBrTXL*21,
     *            mxBrTblLB = mxBrTblLA)
      parameter ( mxPrTXL = 60, mxPrTblLA=mxPrTXL*21,
     *            mxPrTblLB = mxPrTblLA)
      parameter ( mxBrTXH = 60, mxBrTblHA=mxBrTXH*21,
     *            mxBrTblHB = mxBrTblHA)
      parameter ( mxPrTXH = 60, mxPrTblH=mxPrTXH*21)
      parameter ( mxBrTXS = 50, mxBrTblSA = mxBrTXS*21,
     *            mxBrTblSB = mxBrTblSA)

c              for muon
      parameter ( mxMuNTX =51, mxMuBrTX=51, mxMuPrTX= 51 )
      parameter ( mxMuNUsize = 101, mxMuNEsize = 31, 
     *            mxMuBrEsize = 31, mxMuPrEsize= 31 )
      parameter ( mxMuBrUsize = 1, mxMuPrUsize = 1 )  ! not used
      parameter ( mxMuNTbl = mxMuNUsize* mxMuNEsize)
      parameter ( mxMuBrTbl = mxMuBrUsize* mxMuBrEsize)
      parameter ( mxMuPrTbl = mxMuPrUsize* mxMuPrEsize)

      structure /bpTbl/    
c          real*8 BrdEdx0(mxBrTXL)        ! for x*dE/dx(v<100 keV)
          real*8 BrTXL(mxBrTXL)
          real*8 BrSTLA(mxBrTblLA, 1)
          real*8 BrSTLB(mxBrTblLB, 1)

          real*8 BrTXH(mxBrTXH) 
          real*8 BrSTHA(mxBrTblHA, 1)
          real*8 BrSTHB(mxBrTblHB, 1)


          real*8 PrTXL(mxPrTXL)
          real*8 PrSTLA(mxPrTblLA, 1)
          real*8 PrSTLB(mxPrTblLB, 1)

          real*8 PrTXH(mxPrTXH)
          real*8 PrSTH(mxPrTblH, 1)     
        
          real*8 BrTXS(mxBrTXS)
          real*8 BrSTSA(mxBrTblSA, 1)
          real*8 BrSTSB(mxBrTblSB, 1)
c              muon
          real*8 MuNTX(mxMuNTX)
          real*8 MuNdEdx0(mxMuNTX)
          real*8 MuNdEdxt(mxMuNTX)


          real*8 MuBrTX(mxMuBrTX)
          real*8 MuBrdEdx0(mxMuBrTX)
          real*8 MuBrdEdxt(mxMuBrTX)

          real*8 MuPrTX(mxMuPrTX)
          real*8 MuPrdEdx0(mxMuPrTX)
          real*8 MuPrdEdxt(mxMuPrTX)

c          real*8 MuNTbl(mxMuNUsize, mxMuNEsize)
          real*8 MuNTbl(mxMuNTbl, 1)
c          real*8 MuBrTbl(mxMuBrUsize, mxMuBrEsize)
          real*8 MuBrTbl(mxMuBrTbl, 1)
c          real*8 MuPrTbl(mxMuPrUsize, mxMuPrEsize)
          real*8 MuPrTbl(mxMuPrTbl, 1)

          
      end structure

==> Epics.uv8.03.tar.gz: epics/ZbpTbl.h <==
      integer mxBrTXL, mxBrTblLA, mxBrTblLB
      integer mxPrTXL, mxPrTblLA, mxPrTblLB
      integer mxBrTXH, mxBrTblHA, mxBrTblHB
      integer mxPrTXH, mxPrTblH
      integer mxBrTXS, mxBrTblSA,  mxBrTblSB

c           for muon interaction
      integer mxMuNTX, mxMuBrTX, mxMuPrTX
      integer mxMuNTbl, mxMuBrTbl, mxMuPrTbl
      integer mxMuNUsize, mxMuNEsize, mxMuBrUsize, 
     *        mxMuBrEsize, mxMuPrUsize,mxMuPrEsize

c      parameter ( mxBrTXL = 60, mxBrTblLA=mxBrTXL*21,
      parameter ( mxBrTXL = 60, mxBrTblLA=mxBrTXL*41,  ! v8.0
     *            mxBrTblLB = mxBrTblLA)
c      parameter ( mxPrTXL = 60, mxPrTblLA=mxPrTXL*21, 
      parameter ( mxPrTXL = 60, mxPrTblLA=mxPrTXL*41,  ! v8.0
     *            mxPrTblLB = mxPrTblLA)
c      parameter ( mxBrTXH = 60, mxBrTblHA=mxBrTXH*21,
      parameter ( mxBrTXH = 60, mxBrTblHA=mxBrTXH*41,   ! v8.0
     *            mxBrTblHB = mxBrTblHA)
c      parameter ( mxPrTXH = 60, mxPrTblH=mxPrTXH*21)
      parameter ( mxPrTXH = 60, mxPrTblH=mxPrTXH*41)    ! v8.0
c////////////
c      parameter ( mxBrTXS = 50, mxBrTblSA = mxBrTXS*21,
c     *            mxBrTblSB = mxBrTblSA)
      parameter ( mxBrTXS = 60, mxBrTblSA = mxBrTXS*41,  ! v8.0
     *            mxBrTblSB = mxBrTblSA)
c////////////
c              for muon
      parameter ( mxMuNTX =51, mxMuBrTX=51, mxMuPrTX= 51 )
      parameter ( mxMuNUsize = 101, mxMuNEsize = 31, 
     *            mxMuBrEsize = 31, mxMuPrEsize= 31 )
      parameter ( mxMuBrUsize = 1, mxMuPrUsize = 1 )  ! not used
      parameter ( mxMuNTbl = mxMuNUsize* mxMuNEsize)
      parameter ( mxMuBrTbl = mxMuBrUsize* mxMuBrEsize)
      parameter ( mxMuPrTbl = mxMuPrUsize* mxMuPrEsize)

      structure /bpTbl/    
c          real*8 BrdEdx0(mxBrTXL)        ! for x*dE/dx(v<100 keV)
          real*8 BrTXL(mxBrTXL)
          real*8 BrSTLA(mxBrTblLA, 1)
          real*8 BrSTLB(mxBrTblLB, 1)

          real*8 BrTXH(mxBrTXH) 
          real*8 BrSTHA(mxBrTblHA, 1)
          real*8 BrSTHB(mxBrTblHB, 1)


          real*8 PrTXL(mxPrTXL)
          real*8 PrSTLA(mxPrTblLA, 1)
          real*8 PrSTLB(mxPrTblLB, 1)

          real*8 PrTXH(mxPrTXH)
          real*8 PrSTH(mxPrTblH, 1)     
        
          real*8 BrTXS(mxBrTXS)
          real*8 BrSTSA(mxBrTblSA, 1)
          real*8 BrSTSB(mxBrTblSB, 1)
c              muon
          real*8 MuNTX(mxMuNTX)
          real*8 MuNdEdx0(mxMuNTX)
          real*8 MuNdEdxt(mxMuNTX)


          real*8 MuBrTX(mxMuBrTX)
          real*8 MuBrdEdx0(mxMuBrTX)
          real*8 MuBrdEdxt(mxMuBrTX)

          real*8 MuPrTX(mxMuPrTX)
          real*8 MuPrdEdx0(mxMuPrTX)
          real*8 MuPrdEdxt(mxMuPrTX)

c          real*8 MuNTbl(mxMuNUsize, mxMuNEsize)
          real*8 MuNTbl(mxMuNTbl, 1)
c          real*8 MuBrTbl(mxMuBrUsize, mxMuBrEsize)
          real*8 MuBrTbl(mxMuBrTbl, 1)
c          real*8 MuPrTbl(mxMuPrUsize, mxMuPrEsize)
          real*8 MuPrTbl(mxMuPrTbl, 1)

          
      end structure
